==> kdebase-3.1.3.tar.bz2: kdebase-3.1.3/kicker/buttons/nonkdeappbutton.h <==
/*****************************************************************

Copyright (c) 1996-2000 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __nonkdeappbutton_h__
#define __nonkdeappbutton_h__

#include "panelbutton.h"

/**
 * Button that contains a non-KDE application
 */
class NonKDEAppButton : public PanelButton
{
    Q_OBJECT

public:
    NonKDEAppButton( const QString& filePath, const QString& icon,
                     const QString& cmdLine, bool inTerm, QWidget* parent );
    NonKDEAppButton( const KConfigGroup& config, QWidget* parent );

    void saveConfig( KConfigGroup& config ) const;

    virtual void properties();

protected slots:
    void slotExec();

protected:
    void initialize( const QString& filePath, const QString& icon,
                     const QString& cmdLine, bool inTerm );
    virtual QString tileName() { return "Exe"; }
    virtual void dropEvent(QDropEvent *ev);
    virtual void dragEnterEvent(QDragEnterEvent *ev);
    QString defaultIcon() const { return "exec"; };

    QString    pathStr;
    QString    iconStr;
    QString    cmdStr;
    bool       term;
};

#endif

==> kdebase-3.3.2.tar.bz2: kdebase-3.3.2/kicker/buttons/nonkdeappbutton.h <==
/*****************************************************************

Copyright (c) 1996-2000 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __nonkdeappbutton_h__
#define __nonkdeappbutton_h__

#include "panelbutton.h"

/**
 * Button that contains a non-KDE application
 */
class NonKDEAppButton : public PanelButton
{
    Q_OBJECT

public:
    NonKDEAppButton( const QString& filePath, const QString& icon,
                     const QString& cmdLine, bool inTerm, QWidget* parent );
    NonKDEAppButton( const KConfigGroup& config, QWidget* parent );

    void saveConfig( KConfigGroup& config ) const;

    virtual void properties();

protected slots:
    void slotExec();

protected:
    void initialize( const QString& filePath, const QString& icon,
                     const QString& cmdLine, bool inTerm );
    virtual QString tileName() { return "URL"; }
    virtual void dropEvent(QDropEvent *ev);
    virtual void dragEnterEvent(QDragEnterEvent *ev);
    QString defaultIcon() const { return "exec"; };

    QString    pathStr;
    QString    iconStr;
    QString    cmdStr;
    bool       term;
};

#endif
